@@ -1,8 +1,3 @@
-"""
-SPDX-License-Identifier: Apache-2.0
-Copyright (c) 2021 IBM Corp.
-"""
-
 import argparse
 import json
 import sys
@@ -45,7 +40,7 @@ def get_policy(mb_refstate_str):
         mb_refstate_data = None
 
     if mb_refstate_data:
-        mb_policy_name = config.MEASUREDBOOT_POLICYNAME
+        mb_policy_name = config.get("verifier", "measured_boot_policy_name", fallback="accept-all")
         # pylint: disable=import-outside-toplevel
         from keylime.elchecking import policies as eventlog_policies
 
