@@ -1,44 +1,31 @@
-"""
-SPDX-License-Identifier: Apache-2.0
-Copyright 2017 Massachusetts Institute of Technology.
-"""
-import os.path
-import tempfile
-
 import requests
-from requests.adapters import HTTPAdapter
+from requests.adapters import DEFAULT_POOLBLOCK, HTTPAdapter
 from requests.packages.urllib3.poolmanager import PoolManager  # pylint: disable=import-error
 
 
 class RequestsClient:
-    def __init__(self, base_url, tls_enabled, ignore_hostname=False, verify_custom: str = False, **kwargs):
+    def __init__(self, base_url, tls_enabled, tls_context=None, ignore_hostname=True, **kwargs):
         if tls_enabled:
             self.base_url = f"https://{base_url}"
         else:
             self.base_url = f"http://{base_url}"
+
         self.session = requests.Session()
-        if ignore_hostname and tls_enabled:
-            self.session.mount("http://", HostNameIgnoreAdapter())
-            self.session.mount("https://", HostNameIgnoreAdapter())
-        self.verify_custom = verify_custom
-        self.temp_dir = None
+
+        if tls_enabled:
+            self.session.mount("http://", HostNameIgnoreAdapter(tls_context, ignore_hostname))
+            self.session.mount("https://", HostNameIgnoreAdapter(tls_context, ignore_hostname))
+
         for arg, value in kwargs.items():
             if isinstance(value, dict):
                 value = self.__deep_merge(getattr(self.session, arg), value)
             setattr(self.session, arg, value)
 
     def __enter__(self):
-        # This is a workaround for SSLContext not being able to load certificates directly
-        if self.verify_custom:
-            self.temp_dir = tempfile.TemporaryDirectory(prefix="keylime_")
-            self.session.verify = os.path.join(self.temp_dir.name, "agent.crt")
-            with open(self.session.verify, "w", encoding="utf-8") as f:
-                f.write(self.verify_custom)
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        if self.temp_dir:
-            self.temp_dir.cleanup()
+        pass
 
     def request(self, method, url, **kwargs):
         return self.session.request(method, self.base_url + url, **kwargs)
@@ -79,7 +66,20 @@ class HostNameIgnoreAdapter(HTTPAdapter):
     It is required because in most cases we don't know the hostname during certificate generation.
     """
 
-    def init_poolmanager(self, connections, maxsize, block=requests.adapters.DEFAULT_POOLBLOCK, **pool_kwargs):
+    def __init__(self, tls_context, ignore_hostname, *args, **kwargs):
+        self._tls_context = tls_context
+        self._ignore_hostname = ignore_hostname
+
+        super().__init__(*args, **kwargs)
+
+    def init_poolmanager(self, connections, maxsize, block=DEFAULT_POOLBLOCK, **pool_kwargs):
+        assert_hostname = False if self._ignore_hostname and self._tls_context else None
         self.poolmanager = PoolManager(
-            num_pools=connections, maxsize=maxsize, block=block, strict=True, assert_hostname=False, **pool_kwargs
+            num_pools=connections,
+            maxsize=maxsize,
+            block=block,
+            strict=True,
+            assert_hostname=assert_hostname,
+            ssl_context=self._tls_context,
+            **pool_kwargs,
         )
