@@ -1,10 +1,3 @@
-#!/usr/bin/env python3
-
-"""
-SPDX-License-Identifier: Apache-2.0
-Copyright 2017 Massachusetts Institute of Technology.
-"""
-
 import ssl
 
 from tornado import httpclient
@@ -12,7 +5,7 @@ from tornado import httpclient
 from keylime import json
 
 
-async def request(method, url, params=None, data=None, context=None, headers=None):
+async def request(method, url, params=None, data=None, context=None, headers=None, timeout=60.0):
 
     http_client = httpclient.AsyncHTTPClient()
     if params is not None and len(list(params.keys())) > 0:
@@ -33,13 +26,19 @@ async def request(method, url, params=None, data=None, context=None, headers=Non
             headers["Content-Type"] = "application/json"
 
     try:
-        req = httpclient.HTTPRequest(url=url, method=method, ssl_options=context, body=data, headers=headers)
+        req = httpclient.HTTPRequest(
+            url=url,
+            method=method,
+            ssl_options=context,
+            body=data,
+            headers=headers,
+            request_timeout=timeout,
+        )
         response = await http_client.fetch(req)
 
     except httpclient.HTTPError as e:
         if e.response is None:
             return TornadoResponse(500, str(e))
-
         return TornadoResponse(e.response.code, e.response.body)
     except ConnectionError as e:
         return TornadoResponse(599, f"Connection error: {str(e)}")
@@ -47,8 +46,10 @@ async def request(method, url, params=None, data=None, context=None, headers=Non
         return TornadoResponse(599, f"SSL connection error: {str(e)}")
     except OSError as e:
         return TornadoResponse(599, f"TCP/IP Connection error: {str(e)}")
+    except Exception as e:
+        return TornadoResponse(599, f"General communication failure: {str(e)}")
     if response is None:
-        return None
+        return TornadoResponse(599, "Unspecified failure in tornado (empty http response)")
     return TornadoResponse(response.code, response.body)
 
 
